@@ -15,6 +15,7 @@ no warnings "experimental::signatures";
 
 use ChordPro::Output::Common;
 use ChordPro::Utils qw( fq qquote demarkup is_true is_ttrue );
+use Ref::Util qw( is_arrayref );
 
 my $re_meta;
 
@@ -98,6 +99,8 @@ sub generate_song ( $s ) {
 	    next if $used{$k};
 	    next if $k =~ /^(?:title|subtitle|songindex|key_.*|chords|numchords)$/;
 	    next if $k =~ /^_/;
+	    next if $k =~ /\./;
+	    next if $k =~ /^bookmark/;
 	    push( @s, map { +"{meta: $k ".fq($_)."}" } @{ $s->{meta}->{$k} } );
 	}
     }
@@ -144,6 +147,15 @@ sub generate_song ( $s ) {
 	push(@s, "") if $tidy;
     }
 
+    if ( $s->{spreadimage} && $variant eq "msp" ) {
+	my $a = $s->{assets}->{$s->{spreadimage}->{id}};
+	if ( $a->{delegate} =~ /^abc$/i && !$a->{uri} ) {
+	    push( @s, "{start_of_" . lc($a->{delegate}) . "}",
+		  @{$a->{data}},
+		  "{end_of_" . lc($a->{delegate}) . "}" );
+	}
+    }
+
     my $ctx = "";
 
     my @elts = @{$s->{body}};
@@ -172,12 +184,35 @@ sub generate_song ( $s ) {
 		    }
 		    elsif ( $elt->{name} eq "label" ) {
 			my $tag = $elt->{value};
-			$t .= ": " . $tag if $tag ne "";
+			if ( $variant eq "msp" ) {
+			    $tag =~ s/\s+/ /g;
+			    $t .= ": " . $tag if $tag ne "";
+			}
+			else {
+			    $tag =~ s/\n/\\n/g;
+			    $t .= " label=\"" . $tag . "\"" if $tag ne "";
+			}
 		    }
 
 		}
 		$t .= "}";
 		push( @s, $t );
+
+		if ( $ctx =~ /^abc$/ ) {
+		    if ( $elt->{id} ) {
+			push( @s, @{$s->{assets}->{$elt->{id}}->{data}} );
+			next;
+		    }
+		    else {
+			pop(@s);
+			$ctx = '';
+			next;
+		    }
+		}
+		elsif ( $ctx =~ /^textblock$/ ) {
+		    push( @s, @{$s->{assets}->{$elt->{id}}->{data}} );
+		    next;
+		}
 	    }
 	}
 
@@ -300,14 +335,15 @@ sub generate_song ( $s ) {
 	    next;
 	}
 
-	if ( $elt->{type} eq "image" ) {
-	    my $uri = $elt->{uri};
+	if ( $elt->{type} eq "image" && !$msp ) {
+	    my $uri = $s->{assets}->{$elt->{id}}->{uri};
 	    if ( $msp && $uri !~ /^id=/ ) {
 		$imgs{$uri} //= keys(%imgs);
 		$uri = sprintf("id=img%02d", $imgs{$uri});
 	    }
-	    my @args = ( "image:", $uri );
+	    my @args = ( "image:", qquote($uri) );
 	    while ( my($k,$v) = each( %{ $elt->{opts} } ) ) {
+		$v = join( ",",@$v ) if is_arrayref($v);
 		push( @args, "$k=$v" );
 	    }
 	    foreach ( @args ) {
@@ -346,6 +382,14 @@ sub generate_song ( $s ) {
 	    next;
 	}
 
+	if ( $elt->{type} eq "control" ) {
+	    if ( $elt->{name} =~ /^(\w+)-(size|color|font)/ ) {
+		my $t = "{$1$2: " . $elt->{value} . "}";
+		push( @s, $t ) unless $t =~ s/^\{\Kchorus/text/r eq $s[-1];
+	    }
+	    next;
+	}
+
 	if ( $elt->{type} eq "ignore" ) {
 	    push( @s, $elt->{text} );
 	    next;
@@ -374,13 +418,11 @@ sub generate_song ( $s ) {
 	require Image::Info;
 
 	# Slurp the image.
-	my $fd;
-	unless ( open( $fd, '<:raw', $url ) ) {
+	my $data = fs_blob($url);
+	unless ( defined $data ) {
 	    warn("$url: $!\n");
 	    next;
 	}
-	my $data = do { local $/; <$fd> };
-	close($fd);
 
 	# Get info.
 	my $info = Image::Info::image_info(\$data);
