@@ -20,7 +20,7 @@ BUILD {
 	{ 'font-family'		    => 'serif',
 	  'font-size'		    => '10',
 	  'color'		    => 'black',
-	  'background-color'	    => 'white',
+	  'background-color'	    => 'none',
 	  'fill'		    => 'currentColor',
 	  'stroke'		    => 'none',
 	  'line-width'		    => 1,
@@ -216,7 +216,7 @@ method push ( @args ) {
 
     ## Presentation attributes.
     for ( keys %$args ) {
-	next if /^element|class|style|id$/;
+	next if /^(element|class|style|id)$/;
 	$ret->{$_} = $args->{$_};
     }
 
